@@ -74,7 +74,7 @@ POSSIBILITY OF SUCH DAMAGES.
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#if GTK_CHECK_VERSION(3,0,0)
+#if GTK_CHECK_VERSION(3, 0, 0)
 #ifdef ENABLE_GIW
 #define ENABLE_GIW_3
 #endif
@@ -82,6 +82,16 @@ POSSIBILITY OF SUCH DAMAGES.
 
 #endif
 
+#ifdef HAVE_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
+
+#ifdef GDK_WINDOWING_WAYLAND
+#ifndef GDK_IS_WAYLAND_DISPLAY
+#define GDK_IS_WAYLAND_DISPLAY(a) FALSE
+#endif
+#endif
+
 #ifdef IS_MINGW
 
 #ifndef WINVER
@@ -104,7 +114,6 @@ typedef PROCESS_INFORMATION *lives_pgid_t;
 #endif
 #endif
 
-
 #else // IS_MINGW
 
 #ifdef GUI_GTK
@@ -114,18 +123,14 @@ typedef PROCESS_INFORMATION *lives_pgid_t;
 #else
 #include <sys/types.h>
 #include <unistd.h>
+
 #endif // GUI_GTK
 
 typedef pid_t lives_pid_t;
 typedef int lives_pgid_t;
 
-
 #endif // IS_MINGW
 
-
-
-
-
 #include <sys/stat.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -145,15 +150,12 @@ typedef int lives_pgid_t;
 #include <stdint.h>
 #include <stdarg.h>
 
-
 #ifndef ulong
 #define ulong unsigned long
 #endif
 
-
 #define QUOTEME(x) #x
 
-
 /// max files is actually 1 more than this, since file 0 is the clipboard
 #define MAX_FILES 65535
 
@@ -173,8 +175,6 @@ typedef int lives_pgid_t;
 #define PREFIX PREFIX_DEFAULT
 #endif
 
-
-
 #ifndef IS_MINGW
 #define LIVES_DIR_SEP "/"
 #define LIVES_STATUS_FILE_NAME ".status"
@@ -321,7 +321,6 @@ typedef struct {
   uint16_t alpha;
 } lives_colRGBA64_t;
 
-
 #include "widget-helper.h"
 
 typedef  void *(*fn_ptr)(void *ptr);
@@ -352,16 +351,12 @@ typedef struct {
   boolean is_ready;
 } xprocess;
 
-
-
-
 typedef struct {
   int afile;
   double seek;
   double vel;
 } lives_audio_track_state_t;
 
-
 #if HAVE_SYSTEM_WEED
 #include <weed/weed.h>
 #include <weed/weed-events.h>
@@ -381,7 +376,7 @@ typedef struct {
 #endif
 
 typedef enum {
-  UNDO_NONE=0,
+  UNDO_NONE = 0,
   UNDO_EFFECT,
   UNDO_RESIZABLE,
   UNDO_MERGE,
@@ -411,19 +406,17 @@ typedef enum {
   UNDO_INSERT_WITH_AUDIO
 } lives_undo_t;
 
-
 /// which stream end should cause playback to finish ?
 typedef enum {
-  NEVER_STOP=0,
+  NEVER_STOP = 0,
   STOP_ON_VID_END,
   STOP_ON_AUD_END
 } lives_whentostop_t;
 
-
 /// cancel reason
 typedef enum {
   /// no cancel
-  CANCEL_NONE=FALSE,
+  CANCEL_NONE = FALSE,
 
   /// user pressed stop
   CANCEL_USER,
@@ -465,19 +458,14 @@ typedef enum {
   CANCEL_USER_PAUSED,
 
   /// special cancel for TV toy
-  CANCEL_KEEP_LOOPING=CANCEL_NONE+100
-
+  CANCEL_KEEP_LOOPING = CANCEL_NONE + 100
 } lives_cancel_t;
 
-
 typedef enum {
-  CANCEL_KILL=0,  ///< normal - kill background processes working on current clip
+  CANCEL_KILL = 0, ///< normal - kill background processes working on current clip
   CANCEL_SOFT     ///< just cancel in GUI (for keep, etc)
 } lives_cancel_type_t;
 
-
-
-
 typedef enum {
   CLIP_TYPE_DISK, ///< imported video, broken into frames
   CLIP_TYPE_YUV4MPEG, ///< yuv4mpeg stream
@@ -487,16 +475,14 @@ typedef enum {
   CLIP_TYPE_VIDEODEV  ///< frames from video device
 } lives_clip_type_t;
 
-
 typedef enum {
-  IMG_TYPE_UNKNOWN=0,
+  IMG_TYPE_UNKNOWN = 0,
   IMG_TYPE_JPEG,
   IMG_TYPE_PNG
 } lives_image_type_t;
 
 #define IMG_TYPE_BEST IMG_TYPE_PNG
 
-
 #define AFORM_SIGNED 0
 #define AFORM_LITTLE_ENDIAN 0
 
@@ -504,14 +490,12 @@ typedef enum {
 #define AFORM_BIG_ENDIAN (1<<1)
 #define AFORM_UNKNOWN 65536
 
-
 typedef enum {
-  LIVES_INTERLACE_NONE=0,
-  LIVES_INTERLACE_BOTTOM_FIRST=1,
-  LIVES_INTERLACE_TOP_FIRST=2
+  LIVES_INTERLACE_NONE = 0,
+  LIVES_INTERLACE_BOTTOM_FIRST = 1,
+  LIVES_INTERLACE_TOP_FIRST = 2
 } lives_interlace_t;
 
-
 #include "pangotext.h"
 
 #define WEED_LEAF_HOST_DEINTERLACE "host_deinterlace" // frame needs deinterlacing
@@ -610,12 +594,9 @@ typedef struct {
   int frameno;
   int last_frameno;
 
-
-
   /////////////////////////////////////////////////////////////
   // see resample.c for new events system
 
-
   // events
   event *events[1];  ///<for block resampler
 
@@ -680,7 +661,6 @@ typedef struct {
 
   char mime_type[256];
 
-
   boolean deinterlace; ///< auto deinterlace
 
   lives_image_type_t img_type;
@@ -710,8 +690,6 @@ typedef struct {
   boolean needs_update; ///< loaded values were incorrect, update header
 } lives_clip_t;
 
-
-
 typedef struct {
   // the following can be assumed TRUE, they are checked on startup
   boolean has_smogrify;
@@ -769,7 +747,6 @@ typedef struct {
 
   short cpu_bits;
 
-
   char *myname_full;
   char *myname;
 
@@ -784,10 +761,8 @@ typedef struct {
   pid_t mainpid;
 
   mode_t umask;
-
 } capability;
 
-
 /// some shared structures
 extern capability *capable;
 
@@ -823,7 +798,6 @@ extern capability *capable;
 # define PRIu64		__PRI64_PREFIX "u"
 #endif // ifndef PRI64d
 
-
 // common defs for mainwindow (retain this order)
 #include "plugins.h"
 #include "colourspace.h"
@@ -835,17 +809,13 @@ extern capability *capable;
 
 extern mainwindow *mainw;
 
-
 // internal player clock
 #include <sys/time.h>
 struct timeval tv;
 
-
 /// type sizes
 extern ssize_t sizint, sizdbl, sizshrt;
 
-
-
 typedef enum {
   CLIP_DETAILS_BPP,
   CLIP_DETAILS_FPS,
@@ -872,10 +842,8 @@ typedef enum {
   CLIP_DETAILS_DECODER_NAME
 } lives_clip_details_t;
 
-
 // some useful functions
 
-
 // dialogs.c
 boolean do_progress_dialog(boolean visible, boolean cancellable, const char *text);
 boolean do_warning_dialog(const char *text);
@@ -897,9 +865,8 @@ int do_error_dialog_with_check_transient(const char *text, boolean is_blocking,
 int do_info_dialog_with_transient(const char *text, boolean is_blocking, LiVESWindow *transient);
 LiVESWidget *create_message_dialog(lives_dialog_t diat, const char *text, LiVESWindow *transient,
                                    int warn_mask_number, boolean is_blocking);
-
 LiVESWidget *create_question_dialog(const char *title, const char *text, LiVESWindow *parent);
-
+LiVESWindow *get_transient_full();
 void do_system_failed_error(const char *com, int retval, const char *addinfo);
 int do_write_failed_error_s_with_retry(const char *fname, const char *errtext, LiVESWindow *transient) WARN_UNUSED;
 void do_write_failed_error_s(const char *filename, const char *addinfo);
@@ -1015,7 +982,6 @@ void pump_io_chan(LiVESIOChannel *iochan);
 
 void do_splash_progress(void);
 
-
 // d_print shortcuts
 void d_print_cancelled(void);
 void d_print_failed(void);
@@ -1029,7 +995,7 @@ void do_text_window(const char *title, const char *text);
 boolean read_file_details(const char *file_name, boolean only_check_for_audio);
 boolean add_file_info(const char *check_handle, boolean aud_only);
 boolean save_file_comments(int fileno);
-boolean reload_clip(int fileno,int maxframe);
+boolean reload_clip(int fileno, int maxframe);
 void wait_for_bg_audio_sync(lives_clip_t *sfile);
 void reget_afilesize(int fileno);
 ulong deduce_file(const char *filename, double start_time, int end);
@@ -1064,7 +1030,6 @@ boolean read_headers(const char *file_name);
 // saveplay.c sets
 void open_set_file(const char *set_name, int clipnum);
 
-
 // saveplay.c scrap file
 boolean open_scrap_file(void);
 boolean open_ascrap_file(void);
@@ -1076,7 +1041,6 @@ void add_to_ascrap_mb(uint64_t bytes);
 
 boolean check_for_disk_space(void);
 
-
 // main.c
 typedef void (*SignalHandlerPointer)(int);
 
@@ -1153,17 +1117,13 @@ void splash_end(void);
 void splash_msg(const char *msg, double pct);
 void add_message_scroller(LiVESWidget *conter);
 void resize_widgets_for_monitor(boolean get_play_times);
-#if GTK_CHECK_VERSION(3,0,0)
+#if GTK_CHECK_VERSION(3, 0, 0)
 void calibrate_sepwin_size(void);
 boolean expose_pim(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data);
 boolean expose_sim(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data);
 boolean expose_eim(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data);
 #endif
 
-
-
-
-
 // system calls in utils.c
 int lives_system(const char *com, boolean allow_error);
 lives_pid_t lives_fork(const char *com);
@@ -1216,7 +1176,6 @@ int lives_cat(const char *from, const char *to, boolean append);
 int lives_echo(const char *text, const char *to, boolean append);
 int lives_ln(const char *from, const char *to);
 
-
 int lives_utf8_strcasecmp(const char *s1, const char *s2);
 
 char *filename_from_fd(char *val, int fd);
@@ -1232,7 +1191,7 @@ int lives_alarm_set(int64_t ticks);
 void lives_alarm_clear(int alarm_handle);
 lives_storage_status_t get_storage_status(const char *dir, uint64_t warn_level, uint64_t *dsval);
 char *lives_format_storage_space_string(uint64_t space);
-
+char *lives_datetime(struct timeval *tv);
 
 int myround(double n);
 void get_dirname(char *filename);
@@ -1333,7 +1292,7 @@ LiVESList *lives_list_append_unique(LiVESList *xlist, const char *add);
 void find_when_to_stop(void);
 int calc_new_playback_position(int fileno, uint64_t otc, uint64_t *ntc);
 void calc_aframeno(int fileno);
-void minimise_aspect_delta(double allowed_aspect,int hblock,int vblock,int hsize,int vsize,int *width,int *height);
+void minimise_aspect_delta(double allowed_aspect, int hblock, int vblock, int hsize, int vsize, int *width, int *height);
 LiVESInterpType get_interp_value(short quality);
 
 LiVESList *lives_list_move_to_first(LiVESList *list, LiVESList *item) WARN_UNUSED;
@@ -1360,11 +1319,9 @@ lives_cancel_t check_for_bad_ffmpeg(void);
 
 //callbacks.c
 
-
 // paramspecial.c
 LiVESPixbuf *mt_framedraw(lives_mt *, LiVESPixbuf *);
 
-
 // effects-weed.c
 livespointer _lives_malloc(size_t size) GNU_MALLOC;
 livespointer lives_memcpy(livespointer dest, livesconstpointer src, size_t n);
@@ -1373,7 +1330,6 @@ void _lives_free(livespointer ptr);
 livespointer lives_calloc(size_t n_blocks, size_t n_block_bytes);
 livespointer _lives_realloc(livespointer ptr, size_t new_size);
 
-
 // pangotext.c
 boolean subtitles_init(lives_clip_t *sfile, char *fname, lives_subtitle_type_t);
 void subtitles_free(lives_clip_t *sfile);
@@ -1392,9 +1348,8 @@ boolean save_srt_subtitles(lives_clip_t *sfile, double start_time, double end_ti
 
 #define LIVES_TV_CHANNEL1 "http://www.serverwillprovide.com/sorteal/livestvclips/livestv.ogm"
 
-
 // round (double) a up to next (integer) multiple of (double) b
-#define CEIL(a,b) ((int)(((double)a+(double)b-.000000001)/((double)b))*b)
+#define CEIL(a, b) ((int)(((double)a + (double)b - .000000001) / ((double)b)) * b)
 
 #ifdef NEED_ENDIAN_TEST
 #undef NEED_ENDIAN_TEST
@@ -1402,7 +1357,6 @@ static int32_t testint = 0x12345678;
 #define IS_BIG_ENDIAN (((char *)&testint)[0] == 0x12)
 #endif
 
-
 char *dummychar;
 
 void break_me(void);
@@ -1448,6 +1402,5 @@ void break_me(void);
 #endif // LIVES_NO_FATAL
 #endif // LIVES_FATAL
 
-
 #endif // #ifndef HAS_LIVES_MAIN_H
 
