@@ -17,9 +17,10 @@
 #define LIVES_HAS_DEVICE_MANAGER 0
 
 typedef enum {
-  LIVES_DISPLAY_TYPE_UNKNOWN=0,
+  LIVES_DISPLAY_TYPE_UNKNOWN = 0,
   LIVES_DISPLAY_TYPE_X11,
-  LIVES_DISPLAY_TYPE_WIN32
+  LIVES_DISPLAY_TYPE_WIN32,
+  LIVES_DISPLAY_TYPE_WAYLAND
 } lives_display_t;
 
 
@@ -109,7 +110,7 @@ boolean lives_object_unref(livespointer); ///< decrease refcount by one: if refc
 
 // remove any "floating" reference and add a new ref
 #ifdef GUI_GTK
-#if GTK_CHECK_VERSION(3,0,0)
+#if GTK_CHECK_VERSION(3, 0, 0)
 livespointer lives_object_ref_sink(livespointer);
 #else
 void lives_object_ref_sink(livespointer);
@@ -155,7 +156,7 @@ boolean lives_pixbuf_saturate_and_pixelate(const LiVESPixbuf *src, LiVESPixbuf *
 #define lives_signal_handlers_block_by_func(instance, func, data) g_signal_handlers_block_by_func(instance, func, data)
 #define lives_signal_handlers_unblock_by_func(instance, func, data) g_signal_handlers_unblock_by_func(instance, func, data)
 #else
-ulong lives_signal_connect(LiVESWidget *widget, const char *signal_name, ulong funcptr, livespointer data);
+ulong lives_signal_connect(LiVESWidget *, const char *signal_name, ulong funcptr, livespointer data);
 boolean lives_signal_handlers_block_by_func(livespointer instance, livespointer func, livespointer data);
 boolean lives_signal_handlers_unblock_by_func(livespointer instance, livespointer func, livespointer data);
 #endif
@@ -166,8 +167,8 @@ boolean lives_signal_handler_unblock(livespointer instance, unsigned long handle
 boolean lives_signal_handler_disconnect(livespointer instance, unsigned long handler_id);
 boolean lives_signal_stop_emission_by_name(livespointer instance, const char *detailed_signal);
 
-boolean lives_grab_add(LiVESWidget *widget);
-boolean lives_grab_remove(LiVESWidget *widget);
+boolean lives_grab_add(LiVESWidget *);
+boolean lives_grab_remove(LiVESWidget *);
 
 boolean lives_widget_set_sensitive(LiVESWidget *, boolean state);
 boolean lives_widget_get_sensitive(LiVESWidget *);
@@ -181,16 +182,18 @@ boolean lives_widget_queue_draw(LiVESWidget *);
 boolean lives_widget_queue_draw_area(LiVESWidget *, int x, int y, int width, int height);
 boolean lives_widget_queue_resize(LiVESWidget *);
 boolean lives_widget_set_size_request(LiVESWidget *, int width, int height);
-boolean lives_widget_set_minimum_size(LiVESWidget *widget, int width, int height);
-boolean lives_widget_set_maximum_size(LiVESWidget *widget, int width, int height);
+boolean lives_widget_set_minimum_size(LiVESWidget *, int width, int height);
+boolean lives_widget_set_maximum_size(LiVESWidget *, int width, int height);
 boolean lives_widget_reparent(LiVESWidget *, LiVESWidget *new_parent);
 
-boolean lives_widget_is_ancestor(LiVESWidget *widget, LiVESWidget *ancestor);
+boolean lives_widget_is_ancestor(LiVESWidget *, LiVESWidget *ancestor);
 
-boolean lives_widget_set_app_paintable(LiVESWidget *widget, boolean paintable);
+boolean lives_widget_set_app_paintable(LiVESWidget *, boolean paintable);
+
+boolean lives_widget_has_focus(LiVESWidget *);
 
 LiVESWidget *lives_event_box_new(void);
-boolean lives_event_box_set_above_child(LiVESEventBox *ebox, boolean set);
+boolean lives_event_box_set_above_child(LiVESEventBox *, boolean set);
 
 LiVESWidget *lives_label_new(const char *text);
 LiVESWidget *lives_label_new_with_mnemonic(const char *text);
@@ -268,6 +271,7 @@ boolean lives_window_set_modal(LiVESWindow *, boolean modal);
 boolean lives_window_set_deletable(LiVESWindow *, boolean deletable);
 boolean lives_window_set_resizable(LiVESWindow *, boolean resizable);
 boolean lives_window_set_keep_below(LiVESWindow *, boolean keep_below);
+boolean lives_window_set_keep_above(LiVESWindow *, boolean keep_below);
 boolean lives_window_set_decorated(LiVESWindow *, boolean decorated);
 
 boolean lives_window_set_default_size(LiVESWindow *, int width, int height);
@@ -276,6 +280,8 @@ boolean lives_window_set_screen(LiVESWindow *, LiVESXScreen *);
 
 boolean lives_widget_get_position(LiVESWidget *, int *x, int *y);
 
+LiVESWidget *lives_window_get_focus(LiVESWindow *);
+
 boolean lives_window_move(LiVESWindow *, int x, int y);
 boolean lives_window_get_position(LiVESWindow *, int *x, int *y);
 boolean lives_window_set_position(LiVESWindow *, LiVESWindowPosition pos);
@@ -336,6 +342,7 @@ LiVESWidget *lives_expander_new_with_mnemonic(const char *label);
 LiVESWidget *lives_expander_new(const char *label);
 LiVESWidget *lives_expander_get_label_widget(LiVESExpander *expander);
 
+boolean lives_label_set_width_chars(LiVESLabel *label, int nchars);
 boolean lives_label_set_halignment(LiVESLabel *, float yalign);
 
 LiVESWidget *lives_combo_new(void);
@@ -638,7 +645,7 @@ LiVESToolItem *lives_menu_tool_button_new(LiVESWidget *icon, const char *label);
 boolean lives_menu_tool_button_set_menu(LiVESMenuToolButton *, LiVESWidget *menu);
 
 
-#if !GTK_CHECK_VERSION(3,10,0)
+#if !GTK_CHECK_VERSION(3, 10, 0)
 
 boolean lives_image_menu_item_set_image(LiVESImageMenuItem *, LiVESWidget *image);
 
@@ -701,7 +708,7 @@ boolean lives_xwindow_set_cursor(LiVESXWindow *, LiVESXCursor *);
 uint32_t lives_timer_add(uint32_t interval, LiVESWidgetSourceFunc function, livespointer data);
 boolean lives_timer_remove(uint32_t timer);
 
-boolean lives_source_remove(ulong handle);
+boolean lives_source_remove(uint32_t handle);
 
 uint32_t lives_accelerator_get_default_mod_mask();
 
@@ -725,6 +732,9 @@ boolean lives_window_set_auto_startup_notification(boolean set);
 
 
 // compound functions (composed of basic functions)
+boolean lives_has_toplevel_focus();
+
+void lives_label_set_hpadding(LiVESLabel *label, int pad);
 
 LiVESWidget *lives_standard_label_new(const char *text);
 LiVESWidget *lives_standard_label_new_with_mnemonic(const char *text, LiVESWidget *mnemonic_widget);
@@ -837,7 +847,7 @@ LiVESWidget *add_fill_to_box(LiVESBox *);
 
 
 typedef enum {
-  LIVES_CURSOR_NORMAL=0,  ///< must be zero
+  LIVES_CURSOR_NORMAL = 0, ///< must be zero
   LIVES_CURSOR_BUSY,
   LIVES_CURSOR_CENTER_PTR,
   LIVES_CURSOR_HAND2,
@@ -868,7 +878,7 @@ typedef struct {
   boolean pack_end;
   boolean line_wrap; // line wrapping for labels
   boolean non_modal; // non-modal for dialogs
-  boolean expand; // whether spin,check,radio buttons should expand
+  lives_expand_t expand; // whether spin,check,radio buttons should expand
   boolean apply_theme; // whether to apply theming to widget
   double scale; // scale factor for all sizes
   int packing_width; // default should be W_PACKING_WIDTH
@@ -911,7 +921,5 @@ const widget_opts_t def_widget_opts = {
 
 extern const widget_opts_t def_widget_opts;
 
-//#endif
-
 #endif
 
